@@ -1268,6 +1268,26 @@ public:
      */
     const char* clientMachine() const;
 
+    /**
+     * returns a comma-separated list of the activities the window is associated with.
+     * FIXME this might be better as a NETRArray ?
+     * @since 4.6
+     */
+    const char* activities() const;
+
+
+    /**
+     * Sets whether the client wishes to block compositing (for better performance)
+     * @since 4.7
+     */
+    void setBlockingCompositing(bool active);
+
+    /**
+     * Returns whether the client wishes to block compositing (for better performance)
+     * @since 4.7
+     */
+    bool isBlockingCompositing() const;
+
     /**
        Places the window frame geometry in frame, and the application window
        geometry in window.  Both geometries are relative to the root window.
