@@ -35,7 +35,6 @@
 //#include <QtGui/QProgressDialog>
 #include <QtGui/QTextBrowser>
 #include <QUiLoader>
-#include <QtDesigner/QFormBuilder>
 #include <QTextCursor>
 #include <QTextBlock>
 
@@ -119,12 +118,12 @@ FormFileWidget::FormFileWidget(QWidget* parent, const QString& startDirOrVariabl
     //KFileDialog::setMode( KFile::File | KFile::LocalOnly );
 
     // slotOk() emits accepted, accept() emits fileSelected()
-    QObject::connect(d->filewidget, SIGNAL(fileSelected(const QString&)), this, SLOT(slotFileSelected(const QString&)));
+    QObject::connect(d->filewidget, SIGNAL(fileSelected(QString)), this, SLOT(slotFileSelected(QString)));
 
-    QObject::connect(d->filewidget, SIGNAL(fileSelected(const QString&)), this, SIGNAL(fileSelected(const QString&)));
-    QObject::connect(d->filewidget, SIGNAL(fileHighlighted(const QString&)), this, SIGNAL(fileHighlighted(const QString&)));
+    QObject::connect(d->filewidget, SIGNAL(fileSelected(QString)), this, SIGNAL(fileSelected(QString)));
+    QObject::connect(d->filewidget, SIGNAL(fileHighlighted(QString)), this, SIGNAL(fileHighlighted(QString)));
     QObject::connect(d->filewidget, SIGNAL(selectionChanged()), this, SIGNAL(selectionChanged()));
-    QObject::connect(d->filewidget, SIGNAL(filterChanged(const QString&)), this, SIGNAL(filterChanged(const QString&)));
+    QObject::connect(d->filewidget, SIGNAL(filterChanged(QString)), this, SIGNAL(filterChanged(QString)));
 
 //     d->impl->setOperationMode(d->mode);
 //     if( d->mimeFilter.count() > 0 )
@@ -734,7 +733,7 @@ QString FormModule::tr(const QString& str, const QString& comment)
 
 QWidget* FormModule::createWidgetFromUI(QWidget* parent, const QString& xml)
 {
-    QFormBuilder builder;
+    QUiLoader loader;
 
     QDomDocument doc("mydocument");
     doc.setContent(xml.toUtf8());
@@ -762,7 +761,7 @@ QWidget* FormModule::createWidgetFromUI(QWidget* parent, const QString& xml)
     QBuffer buffer(&ba);
     buffer.open(QIODevice::ReadOnly);
 
-    QWidget* widget = builder.load(&buffer, parent);
+    QWidget* widget = loader.load(&buffer, parent);
     if( widget && parent && parent->layout() )
         parent->layout()->addWidget(widget);
     return widget;
@@ -773,11 +772,11 @@ QWidget* FormModule::createWidgetFromUIFile(QWidget* parent, const QString& file
     QFile file(filename);
     if( ! file.exists() ) {
         kDebug() << QString("Kross::FormModule::createWidgetFromUIFile: There exists no such file \"%1\"").arg(filename);
-        return false;
+        return 0;
     }
     if( ! file.open(QFile::ReadOnly) ) {
         kDebug() << QString("Kross::FormModule::createWidgetFromUIFile: Failed to open the file \"%1\"").arg(filename);
-        return false;
+        return 0;
     }
     const QString xml = file.readAll();
     file.close();
